@@ -1,8 +1,6 @@
 package Moose::Exception::CannotFixMetaclassCompatibility;
-BEGIN {
-  $Moose::Exception::CannotFixMetaclassCompatibility::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CannotFixMetaclassCompatibility::VERSION = '2.1204';
+our $VERSION = '2.4000';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Class';
@@ -24,4 +22,5 @@ sub _build_message {
     "Can't fix metaclass incompatibility for $class_name because it is not pristine.";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
