@@ -1,8 +1,6 @@
 package Moose::Exception::CouldNotLocateTypeConstraintForUnion;
-BEGIN {
-  $Moose::Exception::CouldNotLocateTypeConstraintForUnion::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CouldNotLocateTypeConstraintForUnion::VERSION = '2.1204';
+our $VERSION = '2.4000';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::TypeConstraint';
@@ -12,4 +10,5 @@ sub _build_message {
     "Could not locate type constraint (".$self->type_name.") for the union";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
